@@ -16,7 +16,7 @@
 """
 import base64
 
-VERSION = "1.227"
+VERSION = "1.231"
 
 PATH_COMMANDS = [
     "bin/create-shell-archive.sh",
@@ -81,6 +81,7 @@ NDT_ONLY = [
     "mfa-code=n_utils.cli:cli_mfa_code",
     "mfa-delete-token=n_utils.cli:cli_mfa_delete_token",
     "mfa-qrcode=n_utils.cli:cli_mfa_to_qrcode",
+    "print-aws-profiles=n_utils.profile_util:print_aws_profiles",
     "profile-expiry-to-env=n_utils.profile_util:profile_expiry_to_env",
     "profile-to-env=n_utils.profile_util:profile_to_env",
     "promote-image=n_utils.cli:cli_promote_image",
@@ -103,6 +104,7 @@ NDT_ONLY = [
     "deploy-connect=n_utils.cli:deploy_connect_contact_flows",
     "export-connect-contact-flow=n_utils.cli:export_connect_contact_flow",
     "list-connect-contact-flows=n_utils.cli:list_connect_contact_flows",
+    "aws-config-to-json=n_utils.profile_util:cli_profiles_to_json",
 ]
 NDT_ONLY_SCRIPT = [
     "bake-docker.sh",
