@@ -38,7 +38,7 @@ def read_expiring_profiles():
     return ret
 
 
-def read_profiles():
+def read_profiles(prefix=None):
     ret = []
     home = expanduser("~")
     credentials = join(home, ".aws", "credentials")
@@ -47,14 +47,16 @@ def read_profiles():
         with open(credentials) as credfile:
             parser.read_file(credfile)
             for profile in parser.sections():
-                ret.append(profile)
+                if profile.startswith(prefix):
+                    ret.append(profile)
     config = join(home, ".aws", "config")
     if isfile(config) and access(config, R_OK):
         parser = ConfigParser()
         with open(config) as configfile:
             parser.read_file(configfile)
             for profile in parser.sections():
-                if profile.startswith("profile ") and profile[8:] not in ret:
+                if profile.startswith("profile ") and profile[8:] not in ret \
+                   and profile[8:].startswith(prefix):
                     ret.append(profile[8:])
     return ret
 
@@ -103,6 +105,20 @@ def read_profile_expiry_epoc(profile):
     return _epoc_secs(parse(read_profile_expiry(profile)).replace(tzinfo=tzutc()))
 
 
+def print_aws_profiles():
+    """Prints profile names from credentials file (~/.aws/credentials) and the conf file (~/.aws/conf) for autocomplete tools"""
+    parser = argparse.ArgumentParser(description=print_aws_profiles.__doc__)
+    if "_ARGCOMPLETE" in os.environ:
+        parser.add_argument(
+            "prefix", help="Prefix of profiles to print", default="", nargs='?'
+        ).completer = ChoicesCompleter(read_profiles())
+        argcomplete.autocomplete(parser)
+    else:
+        parser.add_argument("prefix", help="Prefix of profiles to print", default="", nargs='?')
+    args = parser.parse_args()
+    print(" ".join(read_profiles(prefix=args.prefix)))
+
+
 def profile_to_env():
     """Prints profile parameters from credentials file (~/.aws/credentials) as eval-able environment variables"""
     parser = argparse.ArgumentParser(description=profile_to_env.__doc__)
@@ -260,6 +276,13 @@ def update_profile(profile, creds):
     with open(credentials, "w") as credfile:
         parser.write(credfile)
 
+def cli_profiles_to_json():
+    """ Prints aws config file contents as json for further parsing and use in other tools """
+    parser = argparse.ArgumentParser(description=cli_profiles_to_json.__doc__)
+    argcomplete.autocomplete(parser)
+    _ = parser.parse_args()
+    profiles_to_json()
+
 def profiles_to_json():
     from collections import OrderedDict
     home = expanduser("~")
